package version

var (
	Release = "1.25.0"
	GitHash string
)
